;
; C64DTV HUMMER type userport joystick driver for the CBM6x0
;
; Marco van den Heuvel, 2010-01-23
;

	.include	"zeropage.inc"
	.include	"extzp.inc"

	.include	"joy-kernel.inc"
	.include	"joy-error.inc"
	.include	"cbm610.inc"
	.include	"extzp.inc"

	.macpack	generic


; ------------------------------------------------------------------------
; Header. Includes jump table

.segment	"JUMPTABLE"

; Driver signature

	.byte	$6A, $6F, $79		; "joy"
	.byte	JOY_API_VERSION		; Driver API version number

; Button state masks (8 values)

	.byte	$01		; JOY_UP
	.byte	$02		; JOY_DOWN
	.byte	$04		; JOY_LEFT
	.byte	$08		; JOY_RIGHT
	.byte	$10		; JOY_FIRE
	.byte	$00		; JOY_FIRE2 unavailable
	.byte	$00		; Future expansion
	.byte	$00		; Future expansion

; Jump table.

	.addr	INSTALL
	.addr	UNINSTALL
	.addr	COUNT
	.addr	READ
	.addr	0		; IRQ entry unused

; ------------------------------------------------------------------------
; Constants

JOY_COUNT	= 1		; Number of joysticks we support


; ------------------------------------------------------------------------
; Data.


.code

; ------------------------------------------------------------------------
; INSTALL routine. Is called after the driver is loaded into memory. If
; possible, check if the hardware is present and determine the amount of
; memory available.
; Must return an JOY_ERR_xx code in a/x.
;

INSTALL:
	lda	#<JOY_ERR_OK
	ldx	#>JOY_ERR_OK
;	rts				; Run into UNINSTALL instead

; ------------------------------------------------------------------------
; UNINSTALL routine. Is called before the driver is removed from memory.
; Can do cleanup or whatever. Must not return anything.
;

UNINSTALL:
	rts


; ------------------------------------------------------------------------
; COUNT: Return the total number of available joysticks in a/x.
;

COUNT:
	lda	#<JOY_COUNT
	ldx	#>JOY_COUNT
	rts

; ------------------------------------------------------------------------
; READ: Read a particular joystick passed in A.
;

READ:
	ldx	#$0f		; Switch to the system bank
	stx	IndReg

; Get the direction bits

	ldy	#CIA::DDRB
	lda	#0
	sta	(cia),y
	ldy	#CIA::PRB
	lda	(cia),y
	and	#$1f
	eor	#$1f
	ldy	ExecReg
	sty	IndReg
	ldx	#0
	rts
